@@ -56,16 +56,17 @@ def cal_erle(micFile = None,testFile =None, refFile =None,targetType=0):
     DR = data_format()
     ERLE,output_std,err,residual_avgdB = c_double(0.0),c_double(0.0),c_double(0.0),c_double(0.0)
     mydll.ERLE_estimation(byref(instruct),byref(teststruct),byref(refstruct),c_double(insamplerate),c_double(outsamplerate),c_double(targetType),byref(ERLE),byref(output_std),byref(residual_avgdB),byref(err))
-
+    print(err.value)
+    print(ERLE.value,output_std.value,residual_avgdB.value)
     if err.value == 0.0:
         return ERLE.value,output_std.value,residual_avgdB.value
     else:
-        return None
+        return None,None,None
 
 
 if __name__ == '__main__':
-    file = r'C:\Users\vcloud_avl\Downloads\agc_eva\speech_gaintable.wav'
-    test = r'C:\Users\vcloud_avl\Downloads\agc_eva\test.wav'
-    ref = ''
-    ERLE,output_std,residual_avgdB = cal_erle(micFile=file,testFile=test,refFile=ref,targetType=0)
-    print(ERLE,output_std,residual_avgdB)
+    micfile = r'C:\Users\vcloud_avl\Documents\我的POPO\0\stdRefFile.wav'
+    test = r'C:\Users\vcloud_avl\Documents\我的POPO\0\mixDstFile.wav'
+    ref = R'C:\Users\vcloud_avl\Documents\我的POPO\0\ref_cn.wav'
+    ERLE,output_std,residual_avgdB = cal_erle(micFile=micfile,testFile=test,refFile=ref,targetType=0)
+    print('ERLE:{},output_std:{},residual_avgdB:{}'.format(ERLE,output_std,residual_avgdB))
