@@ -31,6 +31,9 @@ def cal_snr_transient(refFile=None, noisetFile=None, testFile=None):
 
 
 if __name__ == '__main__':
+    speech = r'C:\Users\vcloud_avl\Documents\我的POPO\nearend_ref.wav'
+    noise = r'C:\Users\vcloud_avl\Documents\我的POPO\noise.wav'
+    test = r'C:\Users\vcloud_avl\Documents\我的POPO\3_noise_suppression_1655194712.wav'
+    print(cal_snr_transient(refFile=speech,noisetFile=noise,testFile=test))
 
-    cal_snr_transient(refFile='speech.wav',noisetFile='transientNoise.wav',testFile='test.wav')
     pass
\ No newline at end of file
