@@ -84,7 +84,7 @@ def write_ctypes_data_2_file_(outFile,outStruct,refsamplerate):
     outarray = outarray.astype(np.int16)
     outf.writeframes(bytes(outarray))
     outf.close()
-constMosResult = {'delay':'No Result','mos':'0.0','Speech Level Gain':'','Noise Level Gain':''}
+constMosResult = {'delay':'No Result','mos':'-0.0','Speech Level Gain':'','Noise Level Gain':''}
 
 class commondata():
     def __init__(self):
